@@ -83,6 +83,7 @@ if python_prefix_matches and python_version_matches:
 
     log_message('initialize_agent = %r', bool(config_file))
     print("777")
+    print("config_file_", config_file)
     if config_file:
         do_insert_path = root_directory not in sys.path
         if do_insert_path:
@@ -98,11 +99,13 @@ if python_prefix_matches and python_version_matches:
             except Exception:
                 pass
 
-        # 探针初始化
-        from fast_tracker import agent, config
+    # 探针初始化
+    print("121212")
+    from fast_tracker import agent, config
 
-        print("888")
-        config.init(collector="127.0.0.1:8111", service="as you wish")
-        print("999")
-        agent.start()
-        print("101010")
+    print("888")
+    # config.init(collector="127.0.0.1:8111", service="as you wish")
+    config.init(collector="fluent:5140", service="as you wish")
+    print("999")
+    agent.start()
+    print("101010")
